==> seedsui-react-5.8.8.tgz: package/lib/Bridge/ap.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["type", "success", "fail", "complete"],
  _excluded2 = ["needResult", "scanType", "desc", "success"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var self = null;
var Bridge = {
  /**
   * 获取当前地理位置
   * @param {Object} params
   * params: {
   * type {String}: 'wgs84'|'gcj02'坐标类型微信默认使用国际坐标'wgs84',
   * }
   * @returns {Object} {latitude: '纬度', longitude: '经度', speed:'速度', accuracy:'位置精度'}
   */
  getLocation: function getLocation() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var _ref = params || {},
      type = _ref.type,
      _success = _ref.success,
      _fail = _ref.fail,
      _complete = _ref.complete,
      otherParams = _objectWithoutProperties(_ref, _excluded);
    self = this;
    // 调用定位
    if (self.locationTask) {
      self.locationTask.push(params);
      return;
    }
    self.locationTask = [];
    console.log('调用支付宝定位...', params);
    window.top.wx.getLocation(_objectSpread(_objectSpread({}, otherParams), {}, {
      type: '2',
      success: function success(res) {
        if (res.longitude && res.latitude) {
          if (_success) _success(res);
        } else {
          if (_fail) _fail(res);
        }
        self.getLocationTask(res);
      },
      fail: function fail(res) {
        if (_fail) _fail(res);
        self.getLocationTask(res);
      },
      complete: function complete(res) {
        if (_complete) _complete(res);
      }
    }));
  },
  /**
   * 扫码
   * @param {Object} params
   * @returns {Object} {latitude: '纬度', longitude: '经度', speed:'速度', accuracy:'位置精度'}
   */
  scanQRCode: function scanQRCode() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var _ref2 = params || {},
      needResult = _ref2.needResult,
      scanType = _ref2.scanType,
      desc = _ref2.desc,
      _success2 = _ref2.success,
      othersParams = _objectWithoutProperties(_ref2, _excluded2);
    window.top.wx.scan(_objectSpread({
      success: function success(res) {
        _success2 && _success2({
          resultStr: res.code
        });
      }
    }, othersParams));
  },
  /**
   * 拍照
   * @param {Object} params
     {
       index: 0, // 当前显示图片索引，默认 0
       current: '', // 当前显示图片的http链接
       urls: [] // 需要预览的图片http链接列表
     }
   */
  previewImage: function previewImage(params) {
    window.top.wx.previewImage({
      urls: params.urls,
      current: (params === null || params === void 0 ? void 0 : params.index) || 0
    });
  },
  /**
   * 关闭窗口
   */
  closeWindow: function closeWindow() {
    var _window$top$wx;
    (_window$top$wx = window.top.wx) === null || _window$top$wx === void 0 ? void 0 : _window$top$wx.popWindow();
  }
};
export default Bridge;

==> seedsui-react-5.8.44.tgz: package/lib/Bridge/ap.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _excluded = ["type", "success", "fail", "complete"],
  _excluded2 = ["needResult", "scanType", "desc", "success"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var self = null;
var Bridge = {
  /**
   * 获取当前地理位置
   * @param {Object} params
   * params: {
   * type {String}: 'wgs84'|'gcj02'坐标类型微信默认使用国际坐标'wgs84',
   * }
   * @returns {Object} {latitude: '纬度', longitude: '经度', speed:'速度', accuracy:'位置精度'}
   */
  getLocation: function getLocation() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var _ref = params || {},
      type = _ref.type,
      _success = _ref.success,
      _fail = _ref.fail,
      _complete = _ref.complete,
      otherParams = _objectWithoutProperties(_ref, _excluded);
    self = this;
    // 调用定位
    if (self.locationTask) {
      self.locationTask.push(params);
      return;
    }
    self.locationTask = [];
    console.log('调用支付宝定位...', params);
    window.top.wx.getLocation(_objectSpread(_objectSpread({}, otherParams), {}, {
      type: '2',
      success: function success(res) {
        if (res.longitude && res.latitude) {
          if (_success) _success(res);
        } else {
          if (_fail) _fail(res);
        }
        self.getLocationTask(res);
      },
      fail: function fail(res) {
        if (_fail) _fail(res);
        self.getLocationTask(res);
      },
      complete: function complete(res) {
        if (_complete) _complete(res);
      }
    }));
  },
  /**
   * 扫码
   * @param {Object} params
   * @returns {Object} {latitude: '纬度', longitude: '经度', speed:'速度', accuracy:'位置精度'}
   */
  scanQRCode: function scanQRCode() {
    var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var _ref2 = params || {},
      needResult = _ref2.needResult,
      scanType = _ref2.scanType,
      desc = _ref2.desc,
      _success2 = _ref2.success,
      othersParams = _objectWithoutProperties(_ref2, _excluded2);
    window.top.wx.scan(_objectSpread({
      success: function success(res) {
        _success2 && _success2({
          resultStr: res.code
        });
      }
    }, othersParams));
  },
  /**
   * 拍照
   * @param {Object} params
     {
       index: 0, // 当前显示图片索引，默认 0
       current: '', // 当前显示图片的http链接
       urls: [] // 需要预览的图片http链接列表
     }
   */
  previewImage: function previewImage(params) {
    window.top.wx.previewImage({
      urls: params.urls,
      current: (params === null || params === void 0 ? void 0 : params.index) || 0
    });
  },
  /**
   * 关闭窗口
   */
  closeWindow: function closeWindow() {
    var _window$top$wx;
    (_window$top$wx = window.top.wx) === null || _window$top$wx === void 0 || _window$top$wx.popWindow();
  }
};
export default Bridge;
